# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newparam(:domain) do
  include EasyType
  include EasyType::Validators::Name

  isnamevar

  desc <<-DESCC
  With this parameter, you identify the domain, where your objects is in.

  The domain name is part of the full qualified name of any WebLogic object on a system. Let's
  say we want to describe a WebLogic server. The full qualified name is:

      wls_server{'domain_name/server_name':
        ensure => present,
        ...
      }

  When you don't specify a domain name, Puppet will use `default` as domain name. For every domain
  you want to manage, you'll have to put a `wls_settings` in your manifest.

  DESCC

  defaultto do
    resource[:name] = "default/#{resource.name}"
    'default'
  end

  to_translate_to_resource do |raw_resource|
    raw_resource['domain']
  end
end

#
#
# These used to be child_of functions. But the child-of function reverses the relation
# from a require, to a bfore when the resource is set to absent. We don't want that
# for these relations. But we still would like to be able to disable the autorequire
#
autorequire(:wls_domain) do
  return if instance_eval('self[:disable_autorequire]', __FILE__, __LINE__)

  domain
end

autorequire(:wls_setting) do
  return if instance_eval('self[:disable_autorequire]', __FILE__, __LINE__)

  domain
end
