# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:default_load_algorithm, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Defines the algorithm to be used for load-balancing between replicated services if none is specified for a particular service. The <tt>round-robin</tt> algorithm cycles through a list of WebLogic Server instances in order. <tt>Weight-based</tt> load balancing improves on the round-robin algorithm by taking into account a pre-assigned weight for each server. In <tt>random</tt> load balancing, requests are routed to servers at random.

  An example on how to use this:

      wls_cluster {a_wls_cluster :
         ...
         default_load_algorithm => 'round-robin'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_cluster:default_load_algorithm']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('DefaultLoadAlgorithm')
end
