# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:fencing_grace_period_millis, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  During automatic migration, if the Cluster Master determines a server to be dead, it waits for this period of time (in milliseconds) before the Cluster Master migrates the service to another server in the cluster.

  An example on how to use this:

      wls_cluster {a_wls_cluster :
         ...
         fencing_grace_period_millis => '30000'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_cluster:fencing_grace_period_millis']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC
  include EasyType::Types::Integer
  data_type("Optional[Variant[Enum['absent'],Integer]]")

  maps_to('FencingGracePeriodMillis')
end
