# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:frontend_http_port, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The name of the HTTP port to which all redirected URLs will be sent.  Sets the FrontendHTTPPort for the default webserver (not virtual hosts) for all the servers in the cluster. Provides a method to ensure that the webapp will always have the correct PORT information, even when the request is coming through a firewall or a proxy. If this parameter is configured, the HOST header will be ignored and the information in this parameter will be used in its place, when constructing the absolute urls for redirects.

  An example on how to use this:

      wls_cluster {a_wls_cluster :
         ...
         frontend_http_port => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_cluster:frontend_http_port']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC
  include EasyType::Types::Integer
  data_type("Optional[Variant[Enum['absent'],Integer[0,9999]]]")

  maps_to('FrontendHTTPPort')
end
