# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:jta_max_unique_name_statistics, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The maximum number of unique transaction names for which statistics are maintained.  The first 1001 unique transaction names are maintained as their own transaction name and stored in each statistic. After the 1001st transaction name is reached, the transaction name is stored as <code>weblogic.transaction.statistics.namedOverflow</code>, and the transaction statistic is also merged and maintained in <code>weblogic.transaction.statistics.namedOverflow</code>.  A transaction name typically represents a category of business transactions, such as "funds-transfer."

  An example on how to use this:

      wls_cluster {a_wls_cluster :
         ...
         jta_max_unique_name_statistics => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_cluster:jta_max_unique_name_statistics']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('JTACluster/%<cluster_name>s/MaxUniqueNameStatistics')
end
