# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:jta_max_xa_call_millis, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Maximum allowed time duration, in milliseconds,  for XA calls to resources. If a particular XA call to a resource exceeds the limit, the resource is declared unavailable.

  An example on how to use this:

      wls_cluster {a_wls_cluster :
         ...
         jta_max_xa_call_millis => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_cluster:jta_max_xa_call_millis']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC
  include EasyType::Types::Integer
  data_type("Optional[Variant[Enum['absent'],Integer]]")

  maps_to('JTACluster/%<cluster_name>s/MaxXACallMillis')
end
