# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:one_way_rmi_for_replication_enabled, :parent => Puppet::Parameter::WlsProperty) do
  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean

  desc <<-DESC
  Indicates if one-way RMI is being used for replication. One-way RMI also requires configuring replication ports on each server in the cluster.

  An example on how to use this:

      wls_cluster {a_wls_cluster :
         ...
         one_way_rmi_for_replication_enabled => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_cluster:one_way_rmi_for_replication_enabled']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type("Optional[Variant[Enum['absent'],Integer[0,1]]]")

  maps_to('OneWayRmiForReplicationEnabled')
end
