# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:servers, :array_matching => :all, :parent => Puppet::Parameter::WlsProperty) do
  include EasyType::Validators::Name
  include EasyType::ArrayProperty

  desc <<-DESC
  The WebLogic servers which are part of this cluster.
  Here is an example on how to use this:

      wls_cluster { 'aCluster':
        ...
        servers => ['server_1','server_2],
        ...
      }

  DESC

  data_type('Optional[Variant[String,Array[String]]]')

  maps_to('Servers/')

  on_apply do
    requested_value = value.to_s == '' ? [] : value
    previous_value = resource.provider.servers || []
    previous_value = [] if previous_value.to_s == 'absent'
    wls_config.execute(template('wls_config/wls_cluster/set_servers.py.erb', binding))
  end
end

child_of(:wls_server, :servers) { self[:servers].collect { |s| "#{domain}/#{s}" } }
