# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:start_root_directory, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The directory that this server uses as its root directory. This directory must be on the computer that hosts the Node Manager. If you do not specify a Root Directory value, the domain directory is used by default.

  An example on how to use this:

      wls_coherence_server {a_wls_coherence_server :
         ...
         start_root_directory => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_coherence_server:start_root_directory']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('CoherenceServerStart/%<coherence_server_name>s/RootDirectory')
end
