# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:unicast_port_auto_adjust, :parent => Puppet::Parameter::WlsProperty) do
  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean

  desc <<-DESC
   Specifies whether the unicast port will be automatically incremented if the port cannot be bound because it is already in use.

  An example on how to use this:

      wls_coherence_server {a_wls_coherence_server :
         ...
         unicast_port_auto_adjust => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_coherence_server:unicast_port_auto_adjust']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type("Optional[Variant[Enum['absent'],Integer[0,1]]]")

  maps_to('UnicastPortAutoAdjust')
end
