# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:pool_fatal_error_codes, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Specifies a comma-separated list of error codes that are treated as fatal errors. These errors include deployment errors that cause a server to fail to boot and connection errors that prevent a connection from being put back in the connection pool.  This optional attribute is used to define fatal error codes, that when specified as the exception code within a <code>SQLException</code> (retrieved by <code>sqlException.getErrorCode()</code>), indicate that a fatal error has occurred and the connection is no longer usable. For Oracle databases the following fatal error codes are predefined within WLS and do not need to be placed in the configuration file:   <ul><li>3113: "end-of-file on communication channel" </li> <li>3114: "not connected to ORACLE" </li> <li>1033: "ORACLE initialization or shutdown in progress" </li> <li>1034: "ORACLE not available" </li> <li>1089: "immediate shutdown in progress - no operations are permitted"</li> <li>1090: "shutdown in progress - connection is not permitted" </li> <li>17002: "I/O exception" </li> </ul>

  An example on how to use this:

      wls_datasource {a_wls_datasource :
         ...
         pool_fatal_error_codes => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_datasource:pool_fatal_error_codes']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('JDBCResource/%<datasource_name>s/JDBCConnectionPoolParams/%<datasource_name>s/FatalErrorCodes')
end
