# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:administration_protocol, :parent => Puppet::Parameter::WlsProperty) do
  extend Puppet_X::EnterpriseModules::WebLogic::DomainPaths # Changes the actual path for domain resource

  desc <<-DESC
  The default protocol for communicating through the administration port or administration channels. (Requires you to enable the administration port or to create an administration channel.)  If requests through the administration port or an administration channel do not specify a protocol, WebLogic Server uses the protocol specified here.  Valid admin protocols are: <ul> <li> t3s <li> https <li> iiops </ul>

  An example on how to use this:

      wls_domain {a_wls_domain :
         ...
         administration_protocol => 't3s'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_domain:administration_protocol']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('AdministrationProtocol')
end
