# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:batch_jobs_executor_service_name, :parent => Puppet::Parameter::WlsProperty) do
  extend Puppet_X::EnterpriseModules::WebLogic::DomainPaths # Changes the actual path for domain resource

  desc <<-DESC
  Returns the name of the application-scoped ManagedExecutorService. This ManagedExecutorService instance will be used to run batch jobs that are submitted from applications deployed to the domain. The ManagedExecutorServiceTemplate by the same name must exit when a batch job is submitted in the domain. If this returns null, then the batch runtime will look to use the default Java EE ManagedExecutorService that is bound to the JNDI name: <code>java:comp/DefaultManagedExecutorService</code>.

  An example on how to use this:

      wls_domain {a_wls_domain :
         ...
         batch_jobs_executor_service_name => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_domain:batch_jobs_executor_service_name']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('BatchJobsExecutorServiceName')
end
