# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:security_administrative_identity_domain, :parent => Puppet::Parameter::WlsProperty) do
  extend Puppet_X::EnterpriseModules::WebLogic::DomainPaths # Changes the actual path for domain resource

  desc <<-DESC
  Domain's administrative identity domain.

  An example on how to use this:

      wls_domain {a_wls_domain :
         ...
         security_administrative_identity_domain => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_domain:security_administrative_identity_domain']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('SecurityConfiguration/%<domain_name>s/AdministrativeIdentityDomain')
end
