# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:security_excluded_domain_names, :parent => Puppet::Parameter::WlsProperty) do
  extend Puppet_X::EnterpriseModules::WebLogic::DomainPaths # Changes the actual path for domain resource

  desc <<-DESC
   Specifies a list of remote domains for which cross-domain check should not be applied.

  An example on how to use this:

      wls_domain {a_wls_domain :
         ...
         security_excluded_domain_names => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_domain:security_excluded_domain_names']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('SecurityConfiguration/%<domain_name>s/ExcludedDomainNames')
end
