# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:security_remote_anonymous_rmi_iiop_enabled, :parent => Puppet::Parameter::WlsProperty) do
  extend  Puppet_X::EnterpriseModules::WebLogic::DomainPaths # Changes the actual path for domain resource
  include ::Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean

  desc <<-DESC
  Returns true if remote anonymous RMI access via IIOP is permitted. If remote anonymous RMI access is not allowed, then client requests that do not specify a username / password may fail.

  An example on how to use this:

      wls_domain {a_wls_domain :
         ...
         security_remote_anonymous_rmi_iiop_enabled => '1'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_domain:security_remote_anonymous_rmi_iiop_enabled']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type("Optional[Variant[Enum['absent'],Integer[0,1]]]")

  maps_to('SecurityConfiguration/%<domain_name>s/RemoteAnonymousRMIIIOPEnabled') {}
end
