# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:server_migration_history_size, :parent => Puppet::Parameter::WlsProperty) do
  extend Puppet_X::EnterpriseModules::WebLogic::DomainPaths # Changes the actual path for domain resource

  desc <<-DESC
  Gets the history size of server migrations.  A value of -1 indicates that the history size is unlimited.

  An example on how to use this:

      wls_domain {a_wls_domain :
         ...
         server_migration_history_size => '-1'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_domain:server_migration_history_size']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC
  include EasyType::Types::Integer
  data_type("Optional[Variant[Enum['absent'],Integer]]")

  maps_to('ServerMigrationHistorySize')
end
