# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift File.join(File.dirname(__FILE__), '../..')
require 'puppet_x/enterprisemodules/weblogic/core'

module Puppet
  Type.newtype(:wls_domain_partition) do
    include Puppet_X::EnterpriseModules::WebLogic::Type

    desc 'This resource allows you to manage domain partitions in an WebLogic 12.2.1 domain.'

    bean_type('Partition')

    ensurable
    parameter :domain
    parameter :name
    parameter :domain_partition_name
    parameter :timeout
    property :virtual_target
    property :root_file_system
    property :systemfs_create_on_demand
    property :systemfs_preserved
    extraproperties do
      property :eager_tracking_of_resource_metrics_enabled
      property :systemfs_notes
      property :systemfs_tags
      property :realm
      property :batch_jobs_data_source_jndi_name
      property :batch_jobs_executor_service_name
      property :data_source_for_job_scheduler
      property :graceful_shutdown_timeout
      property :ignore_sessions_during_shutdown
      property :job_scheduler_table_name
      property :max_concurrent_long_running_requests
      property :max_concurrent_new_threads
      property :notes
      property :parallel_deploy_application_modules
      property :parallel_deploy_applications
      property :partition_id
      property :partition_life_cycle_timeout_val
      property :partition_work_manager
      property :partition_work_manager_ref
      property :primary_identity_domain
      property :rcm_historical_data_buffer_limit
      property :resource_deployment_plan_external_descriptors
      property :resource_deployment_plan_path
      property :resource_deployment_plan
      property :resource_manager
      property :resource_manager_ref
      property :startup_timeout
      property :tags
      property :upload_directory_name
    end

    add_title_attributes(:domain_partition_name)
  end
end
