# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:dynamic_cluster_shutdown_timeout_seconds, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Get the timeout period (in seconds) used by the Elasticity Framework while gracefully shutting down a server. If the server does not shut down before the specified timeout period, the server will be forcibly shut down. With a negative time value, no timeout will be applied.

  An example on how to use this:

      wls_dynamic_cluster {a_wls_dynamic_cluster :
         ...
         dynamic_cluster_shutdown_timeout_seconds => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_dynamic_cluster:dynamic_cluster_shutdown_timeout_seconds']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC
  include EasyType::Types::Integer
  data_type("Optional[Variant[Enum['absent'],Integer]]")

  maps_to('DynamicClusterShutdownTimeoutSeconds')
end
