# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:maximum_dynamic_server_count, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Get the maximum number of server instances allowed to be created. This value should be set to the number of servers expected to be in the cluster. The specified number of servers are dynamically added to the configuration at runtime and associated ServerLifeCycleRuntimeMBeans are created.

  An example on how to use this:

      wls_dynamic_cluster {a_wls_dynamic_cluster :
         ...
         maximum_dynamic_server_count => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_dynamic_cluster:maximum_dynamic_server_count']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC
  include EasyType::Types::Integer
  data_type("Optional[Variant[Enum['absent'],Integer]]")

  maps_to('MaximumDynamicServerCount')
end
