# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:min_dynamic_cluster_size, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Get the minimum number of running server instances that the Elasticity Framework will attempt to keep in the dynamic cluster.

  An example on how to use this:

      wls_dynamic_cluster {a_wls_dynamic_cluster :
         ...
         min_dynamic_cluster_size => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_dynamic_cluster:min_dynamic_cluster_size']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC
  include EasyType::Types::Integer
  data_type("Optional[Variant[Enum['absent'],Integer]]")

  maps_to('MinDynamicClusterSize')
end
