# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:server_name_prefix, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The server name prefix is used to specify the naming convention when creating server names. When the server name prefix is defined, server names are calculated with the specified prefix followed by the index starting with 1.

  An example on how to use this:

      wls_dynamic_cluster {a_wls_dynamic_cluster :
         ...
         server_name_prefix => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_dynamic_cluster:server_name_prefix']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('ServerNamePrefix')
end
