# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:seconds_between_restarts, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Specifies the amount of time, in seconds, to wait in between attempts to restart a failed service instance.

  An example on how to use this:

      wls_file_persistence_store {a_wls_file_persistence_store :
         ...
         seconds_between_restarts => '30'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_file_persistence_store:seconds_between_restarts']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC
  include EasyType::Types::Integer
  data_type("Optional[Variant[Enum['absent'],Integer]]")

  maps_to('SecondsBetweenRestarts')
end
