# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:initial_context_factory, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The initial context factory to use to connect. This class name depends on the JNDI provider and the vendor you are using. The value corresponds to the standard JNDI property, <code>java.naming.factory.initial</code>.

  An example on how to use this:

      wls_foreign_jndi_provider {a_wls_foreign_jndi_provider :
         ...
         initial_context_factory => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_foreign_jndi_provider:initial_context_factory']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('InitialContextFactory')
end
