# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
require "#{File.dirname(__FILE__)}/../foreign_server_object_property"

newproperty(:connection_health_checking, :parent => Puppet::Parameter::WlsProperty) do
  extend ForeignServerObjectProperty

  desc <<-DESC
  Controls connection health checking for JMS resource reference pools that access this JMS foreign connection factory mapping. The default value is <code>Enabled</code>. Oracle recommends selecting <code>Disabled</code> only when directed to do so by customer support.

  An example on how to use this:

      wls_foreign_server_object {a_wls_foreign_server_object :
         ...
         connection_health_checking => 'enabled'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_foreign_server_object:connection_health_checking']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('ConnectionHealthChecking') {}
end
