# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:inserts_per_batch_maximum, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The maximum number of table rows that are inserted per database call.  <ul> <li> When possible, a JDBC store uses JDBC 3.0 batching to batch concurrent client requests. </li>  <li> Both the maximum batch size for concurrent inserts and for concurrent writes are configurable. </li>  <li> To disable JDBC 3.0 batching, set the maximum batch size to 1. </li>  <li> The maximum batch size has no effect on the maximum number of concurrent client requests. </li> </ul>

  An example on how to use this:

      wls_jdbc_persistence_store {a_wls_jdbc_persistence_store :
         ...
         inserts_per_batch_maximum => '20'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_jdbc_persistence_store:inserts_per_batch_maximum']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC
  include EasyType::Types::Integer
  data_type("Optional[Variant[Enum['absent'],Integer]]")

  maps_to('InsertsPerBatchMaximum')
end
