# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:delivery_default_delivery_mode, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The default delivery mode used for messages when a delivery mode is not explicitly defined.   All messages with a DefaultDeliveryMode of <code>null</code> that are produced on a connection created with this factory will receive this value. Message producers can get the delivery mode explicitly by calling the <code> javax.jms.MessageProducer.getDeliveryMode()</code> method.  This attribute is dynamic. It can be changed at any time. However, changing the value does not affect existing connections. It only affects new connections made with this connection factory.

  An example on how to use this:

      wls_jms_connection_factory {a_wls_jms_connection_factory :
         ...
         delivery_default_delivery_mode => 'Persistent'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_jms_connection_factory:delivery_default_delivery_mode']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('DefaultDeliveryParams/%<connection_factory_name>s/DefaultDeliveryMode')
end
