# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift File.join(File.dirname(__FILE__), '../..')
require 'puppet_x/enterprisemodules/weblogic/core'

module Puppet
  Type.newtype(:wls_jms_sort_destination_key) do
    include Puppet_X::EnterpriseModules::WebLogic::Type

    desc <<-DESCC
    This resource allows you to manage the sort destination key in a JMS module of a WebLogic domain.

    Here is an example on how you should use this:

        wls_jms_sort_destination_key { 'jmsClusterModule:JMSPriority':
          ensure        => 'present',
          key_type      => 'Int',
          property_name => 'JMSPriority',
          sort_order    => 'Descending',
        }

    In this example you are managing a JMS sort destination key in the default domain. When you want to
    manage a JMS sort destination key in a specific domain, you can use:

        wls_jms_sort_destination_key { 'my_domain/jmsClusterModule:JMSRedelivered':
          ensure        => 'present',
          key_type      => 'Boolean',
          property_name => 'JMSRedelivered',
          sort_order    => 'Ascending',
        }

    DESCC

    bean_path('/JMSSystemResources/%<jmsmodule>s/JMSResource/%<jmsmodule>s/DestinationKeys')
    bean_type('DestinationKey')

    ensurable
    parameter :key_name
    parameter :domain
    parameter :name
    parameter :jmsmodule

    property  :key_type
    property  :property_name
    property  :sort_order
    parameter :timeout
    extraproperties do
      property :notes
      #
      # Weblogic 12.2.1 new properties
      #
    end

    add_title_attributes(:jmsmodule, :key_name) do
      /(.+):(.+)$/
    end
  end
end
