# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:debug_enabled, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Specifies whether communication with this Node Manager needs to be debugged. When enabled, connections to the NodeManager from the server or clients on the server will result in more information sent to the server log.

  An example on how to use this:

      wls_machine {a_wls_machine :
         ...
         debug_enabled => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_machine:debug_enabled']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean
  data_type("Optional[Variant[Enum['absent'],Integer[0,1]]]")

  maps_to('NodeManager/%<machine_name>s/DebugEnabled')
end
