# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:listen_port, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The port number of the NodeManager for the server or clients on the server to use when connecting to the NodeManager instance.

  An example on how to use this:

      wls_machine {a_wls_machine :
         ...
         listen_port => '5556'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_machine:listen_port']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC
  include EasyType::Types::Integer
  data_type("Optional[Variant[Enum['absent'],Integer]]")

  maps_to('NodeManager/%<machine_name>s/ListenPort')
end
