# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:nm_type, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Returns the node manager type for the server or clients on the server to use when connecting to the NodeManager instance.

  An example on how to use this:

      wls_machine {a_wls_machine :
         ...
         nm_type => 'SSL'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_machine:nm_type']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('NodeManager/%<machine_name>s/NMType')
end
