# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift File.dirname(__FILE__)
$LOAD_PATH.unshift File.join(File.dirname(__FILE__), '../../../easy_type/lib')
require 'puppet/parameter/boolean'
require 'puppet_x/enterprisemodules/weblogic/core'
# doc
module Puppet
  Type.newtype(:wls_managed_executor_service_template) do
    include Puppet_X::EnterpriseModules::WebLogic::Type

    desc <<-DESC
    Weblogic Server provides a preconfigured, default ManagedExecutorService for each application, and applications can easily use it in web or EJB components
    without any configuration.

    This resource allows you to manage a ManagedExecutorService in an WebLogic domain.

    Here is an example on how you should use this:

        wls_managed_executor_service_template { 'default/ManagedExecutorServiceTemplate-0':
          ensure                               => 'present',
          deployment_order                     => '1000',
          long_running_priority                => '5',
          max_concurrent_long_running_requests => '10',
          target                               => ['ClusterJMS'],
          targettype                           => ['Cluster'],
        }

    DESC

    bean_type('ManagedExecutorServiceTemplate')

    ensurable
    parameter :domain
    parameter :name
    parameter :template_name
    parameter :timeout

    property :target
    property :targettype
    property :max_concurrent_long_running_requests
    property :long_running_priority
    property :dispatch_policy
    property :deployment_order
    property :notes
    #
    # The extra properties are only enabled when they are explicitly enabled in the wls_setting
    # for the current domain. Else they are ignored.
    #
    extraproperties do
    end

    add_title_attributes(:template_name)
  end
end
