# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:started, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Specifies the initial operating state of a targeted messaging bridge instance.  <ul> <li> If enabled, the messaging bridge instance forwards messages (running). </li>  <li> If not enabled, the messaging bridge instance does not forward messages (temporarily stopped). </li> </ul>  After a messaging bridge has started forwarding messages (running), use <code>Started</code> to temporarily suspend an active messaging bridge instance or restart an stopped messaging bridge instance.  <ul> <li> Select the <code>Started</code> checkbox to start a messaging bridge instance that has been temporarily stopped. </li>  <li> Clear the <code>Started</code> checkbox to temporarily stop a messaging bridge instance that was running. </li>  <li> This value does not indicate the run-time state of a messaging bridge instance. </li> </ul>

  An example on how to use this:

      wls_messaging_bridge {a_wls_messaging_bridge :
         ...
         started => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_messaging_bridge:started']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type("Optional[Variant[Enum['absent'],Integer[0,1]]]")

  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean

  maps_to('Started')
end
