# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:number_of_restart_attempts, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Specifies how many restart attempts to make before migrating the failed service.  Note that these are consecutive attempts. If the value is set to 6, and the service restart fails 5 times before succeeding, but then fails again later, it will not instantly migrate. Each failure gets its own count of restart attempts.  A value of 0 is identical to setting {@link #getRestartOnFailure} to false. A value of -1 indicates the service should  never be migrated; instead, it will be restarted until it either works or the server shuts down.

  An example on how to use this:

      wls_migratable_target {a_wls_migratable_target :
         ...
         number_of_restart_attempts => '6'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_migratable_target:number_of_restart_attempts']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type("Optional[Variant[Enum['absent'],Integer]]")

  maps_to('NumberOfRestartAttempts')
end
