# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:post_script, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Specifies the path to the post-migration script to run after a migratable target is fully deactivated. The script must be in the <code>MIDDLEWARE_HOME/user_projects/domains/mydomain/bin/service_migration</code> directory.  After the migratable target is deactivated, if there is a script specified, and Node Manager is available, then the script will run. Specifying a script without an available Node Manager will result in an error upon migration.

  An example on how to use this:

      wls_migratable_target {a_wls_migratable_target :
         ...
         post_script => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_migratable_target:post_script']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('PostScript')
end
