# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:driver_use_password_indirection, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
   Specifies whether the database credentials are to be obtained from the credential mapper using the "user" property as the key. When true, the credentials are obtained from the credential mapper. When false, the database user name and password are obtained from the "user" property and Password element, respectively.

  An example on how to use this:

      wls_multi_datasource {a_wls_multi_datasource :
         ...
         driver_use_password_indirection => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_multi_datasource:driver_use_password_indirection']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC
  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean
  data_type("Optional[Variant[Enum['absent'],Integer[0,1]]]")

  maps_to('JDBCResource/%<multi_datasource_name>s/JDBCDriverParams/%<multi_datasource_name>s/UsePasswordIndirection')
end
