# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:oracle_affinity_policy, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Specifies the affinity policy for the datasource. Options include: <ul> <li>Transaction: Transaction affinity</li> <li>Session: Web-session affinity</li> <li>Data: Data affinity</li> </ul> The default value is Session.

  An example on how to use this:

      wls_multi_datasource {a_wls_multi_datasource :
         ...
         oracle_affinity_policy => 'Session'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_multi_datasource:oracle_affinity_policy']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('JDBCResource/%<multi_datasource_name>s/JDBCOracleParams/%<multi_datasource_name>s/AffinityPolicy')
end
