# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:pool_connection_reserve_timeout_seconds, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The number of seconds after which a call to reserve a connection from the connection pool will timeout. When set to <code>0</code>, a call will never timeout. When set to <code>-1</code>, a call will timeout immediately.

  An example on how to use this:

      wls_multi_datasource {a_wls_multi_datasource :
         ...
         pool_connection_reserve_timeout_seconds => '10'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_multi_datasource:pool_connection_reserve_timeout_seconds']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC
  include EasyType::Types::Integer
  data_type("Optional[Variant[Enum['absent'],Integer]]")

  maps_to('JDBCResource/%<multi_datasource_name>s/JDBCConnectionPoolParams/%<multi_datasource_name>s/ConnectionReserveTimeoutSeconds')
end
