# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:pool_highest_num_waiters, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The maximum number of connection requests that can concurrently block threads while waiting to reserve a connection from the data source's connection pool.

  An example on how to use this:

      wls_multi_datasource {a_wls_multi_datasource :
         ...
         pool_highest_num_waiters => '2147483647'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_multi_datasource:pool_highest_num_waiters']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC
  include EasyType::Types::Integer
  data_type("Optional[Variant[Enum['absent'],Integer]]")

  maps_to('JDBCResource/%<multi_datasource_name>s/JDBCConnectionPoolParams/%<multi_datasource_name>s/HighestNumWaiters')
end
