# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:xa_end_only_once, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Specifies that <code>XAResource.end()</code> is called only once for each pending <code>XAResource.start()</code>.  This option prevents the XA driver from calling <code>XAResource.end(TMSUSPEND)</code> and <code>XAResource.end(TMSUCCESS)</code> successively. Only applies to data sources that use an XA driver.  Use this setting to work around specific problems with JDBC XA drivers.

  An example on how to use this:

      wls_multi_datasource {a_wls_multi_datasource :
         ...
         xa_end_only_once => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_multi_datasource:xa_end_only_once']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean
  data_type("Optional[Variant[Enum['absent'],Integer[0,1]]]")

  maps_to('JDBCResource/%<multi_datasource_name>s/JDBCXAParams/%<multi_datasource_name>s/XaEndOnlyOnce')
end
