# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:unit_of_order_routing, :parent => Puppet::Parameter::WlsProperty) do
  extend SAFImportedDestinationObjectProperty

  desc <<-DESC
  Specifies the type of routing used to find a SAF agent when using the message Unit-of-Order feature.  <ul> <li><code>Hash</code> indicates that producers use the hash code of a message Unit-of-Order to find a SAF agent. </li>  <li><code>PathService</code> indicates that producers use the Path Service to find a SAF agent. </li> </ul>

  An example on how to use this:

      wls_saf_imported_destination_object {a_wls_saf_imported_destination_object :
         ...
         unit_of_order_routing => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_saf_imported_destination_object:unit_of_order_routing']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  maps_to('UnitOfOrderRouting')
end
