# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:compression_threshold, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The number of bytes for a serialized message body so that any message that exceeds this limit triggers message compression when the message is about to be sent across a SAF agent's JVM boundary.  The compression will occur on the sending-side SAF agent's JVM if the message body size exceeds the threshold limit.

  An example on how to use this:

      wls_saf_remote_context {a_wls_saf_remote_context :
         ...
         compression_threshold => '2147483647'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_saf_remote_context:compression_threshold']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  maps_to('CompressionThreshold')
end
