# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift File.join(File.dirname(__FILE__), '../..')
require 'puppet_x/enterprisemodules/weblogic/core'

module Puppet
  Type.newtype(:wls_security_realm) do
    include Puppet_X::EnterpriseModules::WebLogic::Type

    desc <<-DESC
    This resource allows you to manage an existing security realm.

    Here is an example on how you can do this:
        wls_security_realm { 'my_domain/myrealm':
          ensure                                      => 'absent',
          auto_restart_on_non_dynamic_changes         => 0,
          combined_role_mapping_enabled               => 1,
          delegate_mbean_authorization                => 1,
          deployable_provider_synchronization_enabled => 0,
          deployable_provider_synchronization_timeout => 60000,
          fully_delegate_authorization                => 0,
          retire_timeout_seconds                      => 60,
          security_dd_model                           => 'DDOnly',
        }

    At this point in type Puppet doesn't support creating a new security realm or
    removing an existing realm.

    DESC

    on_create do
      fail 'Creating a security realm with Puppet is not supported.'
    end

    on_destroy do
      fail 'Removing a security realm with Puppet is not supported.'
    end

    ensurable

    bean_type('SecurityConfiguration')
    bean_path('/SecurityConfiguration/%<domain_name>s/Realms')

    parameter :domain
    parameter :name
    parameter :realm_name
    parameter :timeout

    property :auto_restart_on_non_dynamic_changes
    property :combined_role_mapping_enabled
    property :delegate_mbean_authorization
    property :deployable_provider_synchronization_enabled
    property :deployable_provider_synchronization_timeout
    property :fully_delegate_authorization
    property :management_identity_domain
    property :retire_timeout_seconds
    property :security_dd_model

    extraproperties do
      property :adjudicator_types
      property :auditor_types
      property :authentication_provider_types
      property :auth_methods
      property :authorizer_types
      property :cert_path_provider_types
      property :credential_mapper_types
      property :default_realm
      property :deploy_credential_mapping_ignored
      property :deploy_policy_ignored
      property :deploy_role_ignored
      property :enable_web_logic_principal_validator_cache
      property :identity_assertion_header_name_precedence
      property :max_web_logic_principals_in_cache
      property :password_validator_types
      property :rdbms_security_store
      property :role_mapper_types
      property :validate_dd_security_data
    end

    add_title_attributes(:realm_name)
  end
end
