# frozen_string_literal: true

newproperty(:deploy_credential_mapping_ignored, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Returns whether credential mapping deployment calls on the security system are ignored or passed to the configured Credential Mapping providers.

  An example on how to use this:

      wls_security_realm {a_wls_security_realm :
         ...
         deploy_credential_mapping_ignored => '1'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_security_realm:deploy_credential_mapping_ignored']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type("Optional[Variant[Enum['absent'],Integer[0,1]]]")

  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean

  maps_to('DeployCredentialMappingIgnored')
end
