# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:ignore_sessions_during_shutdown, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Indicates whether a graceful shutdown operation drops all HTTP sessions immediately. If this is set to <code>false</code>, a graceful shutdown operation waits for HTTP sessions to complete or timeout.

  An example on how to use this:

      wls_server {a_wls_server :
         ...
         ignore_sessions_during_shutdown => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server:ignore_sessions_during_shutdown']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean
  data_type("Optional[Variant[Enum['absent'],Integer[0,1]]]")

  maps_to('IgnoreSessionsDuringShutdown')
end
