# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:log_logger_severity_properties, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The configuration of the different logger severities keyed by name. The values are one of the predefined Severity strings namely Emergency, Alert, Critical, Error, Warning, Notice, Info, Debug, Trace.

  An example on how to use this:

      wls_server {a_wls_server :
         ...
         log_logger_severity_properties => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server:log_logger_severity_properties']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  maps_to('Log/%<server_name>s/LoggerSeverityProperties')
end
