# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:log_monitoring_enabled, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Enable or disable log monitoring.

  An example on how to use this:

      wls_server {a_wls_server :
         ...
         log_monitoring_enabled => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server:log_monitoring_enabled']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean
  data_type("Optional[Variant[Enum['absent'],Integer[0,1]]]")

  maps_to('Log/%<server_name>s/LogMonitoringEnabled')
end
