# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:ssl_server_key_file_name, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The full directory location of the private key file (<code>.der</code> or <code>.pem</code>) for the server.  The pathname should either be absolute or relative to the directory from which the server is booted. This field provides backward compatibility for security configurations that store private keys in files. For a more secure deployment, Oracle recommends saving private keys in keystores.  The file extension (<code>.der</code> or <code>.pem</code>) indicates the method that should be used to read the file.

  An example on how to use this:

      wls_server {a_wls_server :
         ...
         ssl_server_key_file_name => 'server-key.der'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server:ssl_server_key_file_name']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  maps_to('SSL/%<server_name>s/ServerKeyFileName')
end
