# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:staging_mode, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The mode that specifies whether an application's files are copied from a source on the Administration Server to the Managed Server's staging area during application preparation.  During application preparation, the application's files are copied from the source on the Administration Server to the Managed Server's staging area. If you specify <code>nostage</code> or <code>external_stage</code>, the copy will not occur. This is useful when the staging area is a shared directory, already containing the application files, or if this is a single server domain. The administrator must ensure that the Managed Server's staging directory is set appropriately. Deployment errors will result if the application is not available during the preparation or activation of the application. Each application can override the staging mode specified here.

  An example on how to use this:

      wls_server {a_wls_server :
         ...
         staging_mode => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server:staging_mode']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  maps_to('StagingMode')
end
