# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:webserver_chunked_transfer_disabled, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Indicates whether the use of Chunk Transfer-Encoding in HTTP/1.1 is enabled.

  An example on how to use this:

      wls_server {a_wls_server :
         ...
         webserver_chunked_transfer_disabled => '1'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server:webserver_chunked_transfer_disabled']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean

  maps_to('WebServer/%<server_name>s/ChunkedTransferDisabled')
end
