# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:sdp_enabled, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Enables Socket Direct Protocol (SDP) on this channel. Enable this attribute when configuring session replication enhancements for Managed Servers in a WebLogic cluster for Oracle Exalogic.

  An example on how to use this:

      wls_server_channel {a_wls_server_channel :
         ...
         sdp_enabled => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server_channel:sdp_enabled']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean
  data_type("Optional[Variant[Enum['absent'],Integer[0,1]]]")

  maps_to('SDPEnabled')
end
