# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:allow_shrinking_priority_request_queue, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Whether the self-tuning should allow shrinking of its priority based queue for pending requests after it has grown in size due to busy workload. Setting this to true would help reduce memory footprint after the busy work period has ended, at the expense of the overhead of growing the request queue again at the next period of busy workload.

  An example on how to use this:

      wls_server_template {a_wls_server_template :
         ...
         allow_shrinking_priority_request_queue => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server_template:allow_shrinking_priority_request_queue']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean
  data_type("Optional[Variant[Enum['absent'],Integer[0,1]]]")

  maps_to('AllowShrinkingPriorityRequestQueue')
end
