# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:eager_thread_local_cleanup, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Specifies whether to clean up all ThreadLocals storage from self-tuning thread pool threads after they have finished processing each work request. By default, the self-tuning thread pool only cleans up ThreadLocal storage in its threads after an application is undeployed to avoid ClassLoader memory leak.

  An example on how to use this:

      wls_server_template {a_wls_server_template :
         ...
         eager_thread_local_cleanup => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server_template:eager_thread_local_cleanup']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean
  data_type("Optional[Variant[Enum['absent'],Integer[0,1]]]")

  maps_to('EagerThreadLocalCleanup')
end
