# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:graceful_shutdown_timeout, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Number of seconds a graceful shutdown operation waits before forcing a shut down. A graceful shutdown gives WebLogic Server subsystems time to complete certain application processing currently in progress. If subsystems are unable to complete processing within the number of seconds that you specify here, then the server will force shutdown automatically.  A value of <code>0</code> means that the server will wait indefinitely for graceful shutdown to complete.  The graceful shutdown timeout applies only to graceful shutdown operations.

  An example on how to use this:

      wls_server_template {a_wls_server_template :
         ...
         graceful_shutdown_timeout => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server_template:graceful_shutdown_timeout']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  maps_to('GracefulShutdownTimeout')
end
