# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:jms_connection_factory_unmapped_res_ref_mode, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
   Use this unmapped resource reference mode to specify the behavior of any resource reference to a Connection Factory when the resource reference does not directly specify a JNDI name by a lookup attribute, or by a mappedName attribute, or by a jndi-name in a descriptor file. If a JNDI name is specified, the resource reference either resolves to the specified object in the JNDI tree or generates a javax.naming.NameNotFoundException.    Following are the available unmapped resource reference modes:  <ul> <li> <code>FailSafe :</code> In this mode, an application JMS connection factory resource reference that does not specify a JNDI name resolves to an object bound to the JNDI tree with the same name as the resource reference name if one can be found in JNDI tree. Otherwise, it throws a javax.naming.NameNotFoundException. A resource reference without a JNDI name never returns a Java EE 7 Default Connection Factory in this mode.  This mode yields pre-12.2.1 WebLogic Server behavior. This mode is Java EE compliant, but the Java EE 7 specification disallows it from being the default mode.  </li> </ul>   <ul> <li> <code>ReturnDefault :</code> This policy is a Java EE compliant mode and it is the default mode. It complies with Java EE 7 while doing a best effort to try delivering FailSafe behavior when it is expected.  (a) If the resource reference name matches the local JNDI name of a configured foreign JMS provider mapping, then WebLogic Server returns the remote JNDI entry from the mapping if it can be resolved, or it throws a javax.naming.NameNotFoundException.   (b) If the resource reference does not match with a foreign JMS provider mapping, and if the resource reference name matches the name of an object that is already bound to the JNDI tree, WebLogic Server returns the JNDI tree object.   (c) If neither (a) nor (b) apply, then WebLogic Server returns "java:comp/DefaultJMSConnectionFactory". In addition, it adds an 'Info' message in the server log indicating that a special behavior has occurred. This log message will occur at most once per application per server boot.  </li> </ul>

  An example on how to use this:

      wls_server_template {a_wls_server_template :
         ...
         jms_connection_factory_unmapped_res_ref_mode => 'ReturnDefault'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server_template:jms_connection_factory_unmapped_res_ref_mode']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  maps_to('JMSConnectionFactoryUnmappedResRefMode')
end
