# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:resolve_dns_name, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Resolve the listen address to use for all T3 communication

  An example on how to use this:

      wls_server_template {a_wls_server_template :
         ...
         resolve_dns_name => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server_template:resolve_dns_name']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean
  data_type("Optional[Variant[Enum['absent'],Integer[0,1]]]")

  maps_to('ResolveDNSName')
end
