# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:ssl_outbound_certificate_validation, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Indicates the server certificate validation rules for outbound SSL.  This attribute always applies to outbound SSL that is part of WebLogic Server (that is, an Administration Server talking to the Node Manager). It does not apply to application code in the server that is using outbound SSL unless the application code uses a <code>weblogic.security.SSL.ServerTrustManager</code> that is configured to use outbound SSL validation.

  An example on how to use this:

      wls_server_template {a_wls_server_template :
         ...
         ssl_outbound_certificate_validation => 'BuiltinSSLValidationOnly'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server_template:ssl_outbound_certificate_validation']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  maps_to('SSL/%<template_name>s/OutboundCertificateValidation')
end
