# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:startup_timeout, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Timeout value for server start and resume operations. If the server fails to start in the timeout period, it will force shutdown.  A value of <code>0</code> means that the server will wait indefinitely for the operation to complete.

  An example on how to use this:

      wls_server_template {a_wls_server_template :
         ...
         startup_timeout => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server_template:startup_timeout']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  maps_to('StartupTimeout')
end
