# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:max_retry_seconds_before_tlog_fail, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The maximum amount of time, in seconds, WebLogic Server tries to recover from a JDBC TLog store failure. If store remains unusable after this period, WebLogic Server set the health state to <code>HEALTH_FAILED</code>. A value of 0 indicates WebLogic Server does not conduct a retry and and immediately sets the health state as <code>HEALTH_FAILED</code>.#{'  '}

  An example on how to use this:

      wls_server_tlog {a_wls_server_tlog :
         ...
         max_retry_seconds_before_tlog_fail => '300'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server_tlog:max_retry_seconds_before_tlog_fail']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  maps_to('MaxRetrySecondsBeforeTLOGFail')
end
