# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:oracle_piggyback_commit_enabled, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Enables committing a batch of INSERT or DELETE operations with the last operation of the transaction instead of issuing a separate commit call to database server which saves a server round trip. This feature benefits applications that have many transactions of a small number of operations or small messages. This feature should be used only when configuring a JDBC store in Oracle Exalogic environments.

  An example on how to use this:

      wls_server_tlog {a_wls_server_tlog :
         ...
         oracle_piggyback_commit_enabled => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server_tlog:oracle_piggyback_commit_enabled']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean
  data_type("Optional[Variant[Enum['absent'],Integer[0,1]]]")

  maps_to('OraclePiggybackCommitEnabled')
end
